package gov.cms.fiss.pricers.esrd.core.rules.bundled_factors.low_volume;

import gov.cms.fiss.pricers.common.application.rules.CalculationRule;
import gov.cms.fiss.pricers.esrd.api.v2.EsrdClaimData;
import gov.cms.fiss.pricers.esrd.api.v2.EsrdClaimPricingRequest;
import gov.cms.fiss.pricers.esrd.api.v2.EsrdClaimPricingResponse;
import gov.cms.fiss.pricers.esrd.core.EsrdPricerContext;
import java.math.RoundingMode;
import org.apache.commons.lang3.StringUtils;

/**
 * Calculates the bundled wage-adjusted training amount.
 *
 * <p>Converted from {@code 3000-LOW-VOL-FULL-PPS-PAYMENT} in the COBOL code.
 *
 * @since 2020
 */
public class CalculateLowVolFinalPaymentAmount
    implements CalculationRule<
        EsrdClaimPricingRequest, EsrdClaimPricingResponse, EsrdPricerContext> {

  @Override
  public void calculate(EsrdPricerContext calculationContext) {
    final EsrdClaimData claimData = calculationContext.getClaimData();

    //     IF (B-COND-CODE = '74')  AND
    //        (B-REV-CODE = '0841' OR '0851')  THEN
    //           COMPUTE H-LV-PPS-FINAL-PAY-AMT  ROUNDED  =
    //                           H-CC-74-PER-DIEM-AMT
    //     ELSE
    //        COMPUTE H-LV-PPS-FINAL-PAY-AMT  ROUNDED  =
    //                H-LV-BUN-ADJUST-BASE-WAGE-AMT +
    //                H-BUN-WAGE-ADJ-TRAINING-AMT
    //     END-IF.
    if (StringUtils.equals(
            EsrdPricerContext.CONDITION_CODE_HOME_SERVICES_74, claimData.getConditionCode())
        && StringUtils.equalsAny(
            claimData.getRevenueCode(),
            EsrdPricerContext.REVENUE_CODE_CONTINUOUS_AMBULATORY_PERITONEAL_DIALYSIS_0841,
            EsrdPricerContext.REVENUE_CODE_CONTINUOUS_CYCLING_PERITONEAL_DIALYSIS_0851)) {
      calculationContext.setLowVolumeFinalPaymentAmount(
          calculationContext.getConditionCode74PerDiemAmount());
    } else {
      calculationContext.setLowVolumeFinalPaymentAmount(
          calculationContext
              .getLowVolumeBundledAdjustedBaseWageAmount()
              .add(calculationContext.getBundledWageAdjustedTrainingAmount())
              .setScale(4, RoundingMode.HALF_UP));
    }
  }
}
